# -*- coding: utf-8 -*-
"""
Fitbit API Library
------------------

:copyright: 2012-2015 ORCAS.
:license: BSD, see LICENSE for more details.
"""

from .api import Fitbit, FitbitOauth2Client

# Meta.

__title__ = 'fitbit'
__author__ = 'Issac Kelly and ORCAS'
__author_email__ = 'bpitcher@orcasinc.com'
__copyright__ = 'Copyright 2012-2015 ORCAS'
__license__ = 'Apache 2.0'

__version__ = '0.2'
__release__ = '0.2'

# Module namespace.

all_tests = []
